@@ -1,7 +1,6 @@
 from transformers import PreTrainedModel
 from transformers.optimization import AdamW
 from pytorch_lightning import LightningModule
-from pytorch_lightning.core.step_result import Result
 from ratsnlp.nlpbook.generation.arguments import GenerationTrainArguments
 from torch.optim.lr_scheduler import ExponentialLR, CosineAnnealingWarmRestarts
 
@@ -33,11 +32,13 @@ class GenerationTask(LightningModule):
         }
 
     def training_step(self, inputs, batch_idx):
-        loss, _, _ = self.model(**inputs)
-        self.log("train_loss", loss, prog_bar=True, logger=True, on_step=True, on_epoch=True)
-        return Result(minimize=loss)
+        # outputs: CausalLMOutputWithCrossAttentions
+        outputs = self.model(**inputs)
+        self.log("train_loss", outputs.loss, prog_bar=False, logger=True, on_step=True, on_epoch=False)
+        return outputs.loss
 
     def validation_step(self, inputs, batch_idx):
-        loss, _, _ = self.model(**inputs)
-        self.log("val_loss", loss, prog_bar=True, logger=True, on_step=True, on_epoch=True)
-        return Result(minimize=loss)
+        # outputs: CausalLMOutputWithCrossAttentions
+        outputs = self.model(**inputs)
+        self.log("val_loss", outputs.loss, prog_bar=False, logger=True, on_step=False, on_epoch=True)
+        return outputs.loss
